﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Media;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.ChartView;

namespace SilverlightApplication15
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }
    }

    public class FakeLogZeroConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            string currentValue = value as string;
            string valueToReplace = string.Format("0{0}001", CultureInfo.CurrentCulture.NumberFormat.NumberDecimalSeparator);
            if (currentValue == valueToReplace)
                return "0";

            return value;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class ScatterPointTemplateSelector : DataTemplateSelector
    {
        public override DataTemplate SelectTemplate(object item, DependencyObject container)
        {
            var itemIndex = (int)item;
            var series = container as ScatterPointSeries;
            var dataPoint = series.DataPoints[itemIndex];
            var chart = series.GetVisualParent<RadCartesianChart>();
            if (dataPoint.YValue > 105)
            {
                return chart.Resources["ellipseTemplate"] as DataTemplate;
            }
            else
            {
                return chart.Resources["rectangleTemplate"] as DataTemplate;
            }
        }
    }

    public class ViewModel : ViewModelBase
    {
        private Random rand = new Random(123456);
        private List<ChartData> data;

        public ViewModel()
        {
            this.Data = this.GetData();
        }

        public List<ChartData> Data
        {
            get
            {
                return this.data;
            }
            set
            {
                if (this.data != value)
                {
                    this.data = value;
                    this.OnPropertyChanged("Data");
                }
            }
        }

        private List<ChartData> GetData()
        {
            List<ChartData> data = new List<ChartData>();
            data.Add(new ChartData(0.001, 100));
            data.Add(new ChartData(0.1, 101));
            data.Add(new ChartData(11, 106));
            data.Add(new ChartData(101, 104));
            data.Add(new ChartData(101, 108));

            return data;
        }
    }

    public class ChartData
    {
        private readonly Brush Red = new SolidColorBrush(Colors.Red);
        private readonly Brush Orange = new SolidColorBrush(Colors.Orange);
        private readonly Brush Green = new SolidColorBrush(Colors.Green);

        public ChartData(double x, double y)
        {
            this.XValue = x;
            this.YValue = y;
        }

        public double XValue { get; set; }
        public double YValue { get; set; }

        public Brush Brush
        {
            get
            {
                if (this.YValue < 102)
                {
                    return Red;
                }
                else if (this.YValue < 105)
                {
                    return Orange;
                }
                else
                {
                    return Green;
                }
            }
        }

    }
}
